#[non_exhaustive]pub enum GeometricError {
ZeroMax,
MaxTooLarge,
InvalidProbability,
}Expand description
Errors that can occur when creating a Geometric level generator.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ZeroMax
The maximum number of levels must be non-zero.
MaxTooLarge
The maximum number of levels must be less than i32::MAX.
InvalidProbability
The probability $q$ must be in the range $(0, 1)$.